==============
 zope.session
==============

.. image:: https://img.shields.io/pypi/v/zope.session.svg
        :target: https://pypi.python.org/pypi/zope.session/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.session.svg
        :target: https://pypi.org/project/zope.session/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.session.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.session

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.session/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.session?branch=master

.. image:: https://readthedocs.org/projects/zopesession/badge/?version=latest
        :target: https://zopesession.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

This package provides interfaces for client identification and session
support and their implementations for the request objects of
`zope.publisher <https://zopepublisher.readthedocs.io/>`_.

Documentation is hosted at https://zopesession.readthedocs.io/
